Module: ActiveDocument

Defined in:
lib/ActiveDocument/active_document.rb,
lib/ActiveDocument/finder.rb,
lib/ActiveDocument/search_match.rb,
lib/ActiveDocument/search_result.rb,
lib/ActiveDocument/search_results.rb,
lib/ActiveDocument/mark_logic_http.rb,
lib/ActiveDocument/mark_logic_query_builder.rb,
lib/ActiveDocument/mark_logic_search_options.rb

Overview

MarkLogicSearchOptions allow you to control exactly how the ActiveDocument::Finder#search method behaves and what additional information may be returned in the ActiveDocument::SearchResults object

Attributes

  • return_facets - if true then facet information is returned in the resultant ActiveDocument::SearchResults object. Default is true

  • value_constraints - this is a #Hash of value constraint names to their options. e.g. search_options_object.value_constraints = => “wits.nctc.gov”, “element” => “Region”

Defined Under Namespace

Classes: ActiveDocumentException, Base, Finder, LoadException, MarkLogicHTTP, MarkLogicQueryBuilder, MarkLogicSearchOptions, PersistenceException, SearchMatch, SearchResult, SearchResults